import { defaultConfig as defaultConfig$1 } from '@cleavelandprice/ngx-lib';
import * as i0 from '@angular/core';
import { Injectable, Optional, Component, ViewChild, EventEmitter, Output, NgModule, SkipSelf } from '@angular/core';
import { Subject, forkJoin } from 'rxjs';
import * as i1$1 from '@angular/material/dialog';
import { MatDialogModule } from '@angular/material/dialog';
import * as i1 from '@angular/common/http';
import { HttpHeaders, HttpRequest, HttpEventType, HttpResponse } from '@angular/common/http';
import * as i3 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i4 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i5 from '@angular/material/list';
import { MatListModule } from '@angular/material/list';
import * as i6 from '@angular/material/core';
import * as i7 from '@angular/material/progress-bar';
import { MatProgressBarModule } from '@angular/material/progress-bar';

const defaultConfig = {
    apiUrl: defaultConfig$1.apiUrl,
    databaseEndpoint: '/upload/database',
    uploadDialogTitle: 'Upload Files',
    uploadPath: null,
    comment: null,
    dbAppId: null,
    externalReferenceId: null,
    uploadButtonText: 'Upload',
    uploadDialogCancelButtonText: 'Cancel',
    uploadDialogFinishButtonText: 'Finish',
    uploadDialogUploadButtonText: 'Upload',
    uploadDialogAddFilesButtonText: 'Add Files'
};

class ServiceConfig {
    constructor() {
        this.uploadPath = null;
        this.dbAppId = null;
        this.externalReferenceId = null;
        this.comment = null;
        // UI configuration
        this.uploadButtonText = null;
        this.uploadDialogTitle = null;
        this.uploadDialogAddFilesButtonText = null;
        this.uploadDialogCancelButtonText = null;
        this.uploadDialogUploadButtonText = null;
        this.uploadDialogFinishButtonText = null;
    }
}

// https://malcoded.com/posts/angular-file-upload-component-with-express
class UploadService {
    constructor(http, config) {
        this.http = http;
        this.config = config;
        this.config = Object.assign(Object.assign({}, defaultConfig), this.config);
    }
    upload(files) {
        // this will be the our resulting map
        const status = {};
        files.forEach(file => {
            // create a new multipart-form for every file
            const formData = new FormData();
            formData.append('file', file, file.name);
            // create a http-post request and pass the form
            // tell it to report the upload progress
            // A 'Destination' header is used to optionally configure the file upload destination (filesystem)
            // A 'DbAppId' header is used to configure the unique identifier of database uploads
            let headers = new HttpHeaders();
            if (this.config.uploadPath) {
                headers = headers.set('Destination', this.config.uploadPath);
            }
            if (this.config.dbAppId) {
                headers = headers.set('DbAppId', this.config.dbAppId);
            }
            if (this.config.externalReferenceId) {
                headers = headers.set('ExternalReferenceId', this.config.externalReferenceId);
            }
            if (this.config.comment) {
                headers = headers.set('Comment', this.config.comment);
            }
            const req = new HttpRequest('POST', `${this.config.apiUrl}${this.config.databaseEndpoint}`, formData, {
                reportProgress: true,
                responseType: 'blob',
                headers
            });
            // create a new progress-subject for every file
            const progress = new Subject();
            // send the http-request and subscribe for progress-updates
            this.http.request(req).subscribe(event => {
                var _a;
                if (event.type === HttpEventType.UploadProgress) {
                    // calculate the progress percentage
                    const percentDone = Math.round(100 * event.loaded / ((_a = event.total) !== null && _a !== void 0 ? _a : 1));
                    // pass the percentage into the progress-stream
                    progress.next(percentDone);
                }
                else if (event instanceof HttpResponse) {
                    // Close the progress-stream if we get an answer form the API
                    // The upload is complete
                    progress.complete();
                }
            });
            // Save every progress-observable in a map of all observables
            status[file.name] = {
                progress: progress.asObservable()
            };
        });
        // return the map of progress.observables
        return status;
    }
    exists(fileName) {
        const query = `${this.config.apiUrl}${this.config.databaseEndpoint}`.toLowerCase().indexOf('filesystem') === -1 ?
            { name: fileName, dbAppId: this.config.dbAppId } :
            { name: fileName, destination: this.config.uploadPath };
        return this.http.post(`${this.config.apiUrl}${this.config.databaseEndpoint}/exists`, query);
    }
    download(request) {
        return this.http.post(`${this.config.apiUrl}${this.config.databaseEndpoint}/stream`, request, { responseType: 'blob' });
    }
    getUploadInfo(request) {
        return this.http.post(`${this.config.apiUrl}${this.config.databaseEndpoint}/info`, request);
    }
}
UploadService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: UploadService, deps: [{ token: i1.HttpClient }, { token: ServiceConfig, optional: true }], target: i0.ɵɵFactoryTarget.Injectable });
UploadService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: UploadService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: UploadService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () {
        return [{ type: i1.HttpClient }, { type: ServiceConfig, decorators: [{
                        type: Optional
                    }] }];
    } });

class UploadDialogComponent {
    constructor(dialogRef, uploadService) {
        this.dialogRef = dialogRef;
        this.uploadService = uploadService;
        this.files = new Set();
        this.existingFileConflict = null;
        this.canBeClosed = true;
        this.primaryButtonText = null;
        this.showCancelButton = true;
        this.uploading = false;
        this.uploadSuccessful = false;
    }
    ngOnInit() {
        this.primaryButtonText = this.uploadService.config.uploadDialogUploadButtonText;
    }
    addFiles() {
        this.file.nativeElement.click();
    }
    onFilesAdded() {
        const files = this.file.nativeElement.files;
        for (const key in files) {
            if (!isNaN(parseInt(key))) {
                // See if the file already exists
                this.uploadService.exists(files[key].name)
                    .subscribe(exists => {
                    if (exists) {
                        this.existingFileConflict = files[key].name;
                    }
                    if (!exists) {
                        this.files.add(files[key]);
                    }
                });
            }
        }
    }
    closeDialog() {
        // if everything was uploaded already, just close the dialog
        if (this.uploadSuccessful) {
            return this.dialogRef.close();
        }
        // set the component state to "uploading"
        this.uploading = true;
        // start the upload and save the progress map
        this.progress = this.uploadService.upload(this.files);
        // convert the progress map into an array
        const allProgressObservables = [];
        for (let key in this.progress) {
            allProgressObservables.push(this.progress[key].progress);
        }
        // Adjust the state variables
        // The OK-button should have the text "Finish" now
        this.primaryButtonText = this.uploadService.config.uploadDialogFinishButtonText;
        // The dialog should not be closed while uploading
        this.canBeClosed = false;
        this.dialogRef.disableClose = true;
        // Hide the cancel-button
        this.showCancelButton = false;
        // When all progress-observables are completed...
        forkJoin(allProgressObservables).subscribe(end => {
            // ... the dialog can be closed again...
            this.canBeClosed = true;
            this.dialogRef.disableClose = false;
            // ... the upload was successful...
            this.uploadSuccessful = true;
            // ... and the component is no longer uploading
            this.uploading = false;
        });
    }
}
UploadDialogComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: UploadDialogComponent, deps: [{ token: i1$1.MatDialogRef }, { token: UploadService }], target: i0.ɵɵFactoryTarget.Component });
UploadDialogComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.1", type: UploadDialogComponent, selector: "ng-component", viewQueries: [{ propertyName: "file", first: true, predicate: ["file"], descendants: true, static: true }], ngImport: i0, template: "<input type=\"file\" #file style=\"display: none\" (change)=\"onFilesAdded()\" multiple />\n\n<div mat-dialog-title id=\"title\">\n  <div>{{ uploadService.config.uploadDialogTitle }}</div>\n  <button [disabled]=\"uploading || uploadSuccessful\" mat-raised-button color=\"primary\" class=\"add-files-btn\" (click)=\"addFiles()\">\n    {{ uploadService.config.uploadDialogAddFilesButtonText }}\n  </button>\n</div>\n\n<div id=\"conflict\" *ngIf=\"existingFileConflict\">\n  {{ existingFileConflict }} already exists on the server and cannot be overwritten\n</div>\n\n<mat-dialog-content>\n  <mat-list>\n    <mat-list-item *ngFor=\"let file of files\">\n      <h4 mat-line>{{file.name}}</h4>\n      <mat-progress-bar *ngIf=\"progress\" mode=\"determinate\" [value]=\"progress[file.name].progress | async\"></mat-progress-bar>\n    </mat-list-item>\n  </mat-list>\n</mat-dialog-content>\n\n<mat-dialog-actions id=\"actions\">\n  <button *ngIf=\"showCancelButton\" mat-button mat-dialog-close>{{ uploadService.config.uploadDialogCancelButtonText }}</button>\n  <button *ngIf=\"files.size > 0\" mat-raised-button color=\"primary\" [disabled]=\"!canBeClosed\" (click)=\"closeDialog()\">{{ primaryButtonText }}</button>\n</mat-dialog-actions>\n", styles: ["#title{display:flex;justify-content:space-between}#actions{display:flex;justify-content:flex-end}#conflict{font-size:.8em;color:red;margin-top:.5em}\n"], dependencies: [{ kind: "directive", type: i3.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i3.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "component", type: i4.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "directive", type: i1$1.MatDialogClose, selector: "[mat-dialog-close], [matDialogClose]", inputs: ["aria-label", "type", "mat-dialog-close", "matDialogClose"], exportAs: ["matDialogClose"] }, { kind: "directive", type: i1$1.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { kind: "directive", type: i1$1.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "directive", type: i1$1.MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "component", type: i5.MatList, selector: "mat-list, mat-action-list", inputs: ["disableRipple", "disabled"], exportAs: ["matList"] }, { kind: "component", type: i5.MatListItem, selector: "mat-list-item, a[mat-list-item], button[mat-list-item]", inputs: ["disableRipple", "disabled"], exportAs: ["matListItem"] }, { kind: "directive", type: i6.MatLine, selector: "[mat-line], [matLine]" }, { kind: "component", type: i7.MatProgressBar, selector: "mat-progress-bar", inputs: ["color", "value", "bufferValue", "mode"], outputs: ["animationEnd"], exportAs: ["matProgressBar"] }, { kind: "pipe", type: i3.AsyncPipe, name: "async" }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: UploadDialogComponent, decorators: [{
            type: Component,
            args: [{ template: "<input type=\"file\" #file style=\"display: none\" (change)=\"onFilesAdded()\" multiple />\n\n<div mat-dialog-title id=\"title\">\n  <div>{{ uploadService.config.uploadDialogTitle }}</div>\n  <button [disabled]=\"uploading || uploadSuccessful\" mat-raised-button color=\"primary\" class=\"add-files-btn\" (click)=\"addFiles()\">\n    {{ uploadService.config.uploadDialogAddFilesButtonText }}\n  </button>\n</div>\n\n<div id=\"conflict\" *ngIf=\"existingFileConflict\">\n  {{ existingFileConflict }} already exists on the server and cannot be overwritten\n</div>\n\n<mat-dialog-content>\n  <mat-list>\n    <mat-list-item *ngFor=\"let file of files\">\n      <h4 mat-line>{{file.name}}</h4>\n      <mat-progress-bar *ngIf=\"progress\" mode=\"determinate\" [value]=\"progress[file.name].progress | async\"></mat-progress-bar>\n    </mat-list-item>\n  </mat-list>\n</mat-dialog-content>\n\n<mat-dialog-actions id=\"actions\">\n  <button *ngIf=\"showCancelButton\" mat-button mat-dialog-close>{{ uploadService.config.uploadDialogCancelButtonText }}</button>\n  <button *ngIf=\"files.size > 0\" mat-raised-button color=\"primary\" [disabled]=\"!canBeClosed\" (click)=\"closeDialog()\">{{ primaryButtonText }}</button>\n</mat-dialog-actions>\n", styles: ["#title{display:flex;justify-content:space-between}#actions{display:flex;justify-content:flex-end}#conflict{font-size:.8em;color:red;margin-top:.5em}\n"] }]
        }], ctorParameters: function () { return [{ type: i1$1.MatDialogRef }, { type: UploadService }]; }, propDecorators: { file: [{
                type: ViewChild,
                args: ['file', { static: true }]
            }] } });

class UploadComponent {
    constructor(dialog, uploadService) {
        this.dialog = dialog;
        this.uploadService = uploadService;
        this.dialogClosed = new EventEmitter();
    }
    ngOnInit() {
        this.uploadButtonText = this.uploadService.config.uploadButtonText ?
            this.uploadService.config.uploadButtonText :
            'Upload';
    }
    openUploadDialog() {
        this.dialog.open(UploadDialogComponent, { width: '50%' })
            .afterClosed().subscribe(() => this.dialogClosed.emit());
    }
}
UploadComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: UploadComponent, deps: [{ token: i1$1.MatDialog }, { token: UploadService }], target: i0.ɵɵFactoryTarget.Component });
UploadComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.1", type: UploadComponent, selector: "cp-upload", outputs: { dialogClosed: "dialogClosed" }, ngImport: i0, template: '<button mat-raised-button (click)="openUploadDialog()">{{ uploadButtonText }}</button>', isInline: true, dependencies: [{ kind: "component", type: i4.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: UploadComponent, decorators: [{
            type: Component,
            args: [{
                    selector: 'cp-upload',
                    template: '<button mat-raised-button (click)="openUploadDialog()">{{ uploadButtonText }}</button>'
                }]
        }], ctorParameters: function () { return [{ type: i1$1.MatDialog }, { type: UploadService }]; }, propDecorators: { dialogClosed: [{
                type: Output
            }] } });

class UploadModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('UploadModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(uploadConfig) {
        return {
            ngModule: UploadModule,
            providers: [
                UploadService,
                { provide: ServiceConfig, useValue: uploadConfig }
            ]
        };
    }
}
UploadModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: UploadModule, deps: [{ token: UploadModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule });
UploadModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.1", ngImport: i0, type: UploadModule, declarations: [UploadComponent,
        UploadDialogComponent], imports: [CommonModule,
        MatButtonModule,
        MatDialogModule,
        MatListModule,
        MatProgressBarModule], exports: [UploadComponent,
        UploadDialogComponent] });
UploadModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: UploadModule, imports: [CommonModule,
        MatButtonModule,
        MatDialogModule,
        MatListModule,
        MatProgressBarModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: UploadModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        UploadComponent,
                        UploadDialogComponent
                    ],
                    imports: [
                        CommonModule,
                        MatButtonModule,
                        MatDialogModule,
                        MatListModule,
                        MatProgressBarModule
                    ],
                    exports: [
                        UploadComponent,
                        UploadDialogComponent
                    ]
                }]
        }], ctorParameters: function () {
        return [{ type: UploadModule, decorators: [{
                        type: Optional
                    }, {
                        type: SkipSelf
                    }] }];
    } });

/**
 * Generated bundle index. Do not edit.
 */

export { ServiceConfig, UploadComponent, UploadDialogComponent, UploadModule, UploadService, defaultConfig };
//# sourceMappingURL=cleavelandprice-ngx-lib-upload.mjs.map
