import { defaultConfig as defaultConfig$1 } from '@cleavelandprice/ngx-lib';
import { ServiceConfig as ServiceConfig$1 } from '@cleavelandprice/ngx-lib/authentication';
import * as i0 from '@angular/core';
import { EventEmitter, Injectable, Optional, Output, NgModule, SkipSelf } from '@angular/core';
import { JwtHelperService } from '@auth0/angular-jwt';
import * as i2 from '@angular/common/http';
import { CommonModule } from '@angular/common';

const defaultConfig = {
    apiUrl: defaultConfig$1.apiUrl,
    authenticateEndpoint: '/authenticate/token',
    tokenName: 'token',
    deferTokenValidation: false
};

class ServiceConfig extends ServiceConfig$1 {
}

class AuthenticationService {
    //#endregion
    //#region Lifecycle
    // If a ServiceConfig object is not provided when the module is imported, then default values are pulled in from default-config.ts.
    constructor(config, http) {
        this.config = config;
        this.http = http;
        //#region Fields
        this.authenticatedChanged = new EventEmitter();
        this.authenticatingChanged = new EventEmitter();
        this.authenticationError = new EventEmitter();
        this.authenticating = false; // Flag set to true while the service is attempting to authenticate the user
        this.authenticated = false; // Flag set to true when the user is successfully authenticated
        this.authenticatedUser = null; // Object representing the authenticated user
        this.config = {
            ...defaultConfig,
            ...config
        };
        if (!this.config.deferTokenValidation) {
            this.checkForExistingToken();
        }
    }
    //#endregion
    //#region Utilities
    //Authenticate the user and store the token in Local Storage
    login(username, password, adminGroup) {
        const request = {
            username: username,
            password: password,
            adminGroup: adminGroup
        };
        this.authenticating = true;
        this.authenticatingChanged.emit(this.authenticating);
        // Sending a 'raw' POST request so that we can tell HttpClient that we are expecting text instead of Json
        // Otherwise, it would throw an error trying to decode Json from the response
        this.http.request('POST', `${this.config.apiUrl}${this.config.authenticateEndpoint}`, { body: request, responseType: 'text' })
            .subscribe({
            next: (token) => {
                if (token) {
                    this.validateUser(token);
                }
                else {
                    this.logout();
                }
            },
            error: (err) => {
                this.authenticating = false;
                this.authenticatingChanged.emit(this.authenticating);
                this.authenticationError.emit(err);
            }
        });
    }
    //Logout the user and delete the token from Local Storage
    logout() {
        if (localStorage.getItem(this.config.tokenName)) {
            localStorage.removeItem(this.config.tokenName);
        }
        this.authenticatedUser = null;
        this.authenticated = false;
        this.authenticatedChanged.emit(false);
    }
    validateUser(token) {
        const jwtHelper = new JwtHelperService();
        const decoded = jwtHelper.decodeToken(token);
        if (jwtHelper.isTokenExpired(token)) {
            this.logout();
            return;
        }
        this.authenticatedUser = {
            admin: decoded.role === 'Admin',
            displayName: decoded.displayName,
            accountName: decoded.winaccountname,
            distinguishedName: decoded.distinguishedName,
            employeeNumber: decoded.employeeNumber,
            memberOf: decoded.memberOf
        };
        localStorage.setItem(this.config.tokenName, token);
        this.authenticated = true;
        this.authenticatedChanged.emit(this.authenticated);
        this.authenticating = false;
        this.authenticatingChanged.emit(this.authenticating);
    }
    checkForExistingToken() {
        const token = localStorage.getItem(this.config.tokenName);
        if (token) {
            this.validateUser(token);
        }
    }
}
AuthenticationService.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: AuthenticationService, deps: [{ token: ServiceConfig, optional: true }, { token: i2.HttpClient }], target: i0.ɵɵFactoryTarget.Injectable });
AuthenticationService.ɵprov = i0.ɵɵngDeclareInjectable({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: AuthenticationService, providedIn: 'root' });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: AuthenticationService, decorators: [{
            type: Injectable,
            args: [{
                    providedIn: 'root'
                }]
        }], ctorParameters: function () { return [{ type: ServiceConfig, decorators: [{
                    type: Optional
                }] }, { type: i2.HttpClient }]; }, propDecorators: { authenticatedChanged: [{
                type: Output
            }], authenticatingChanged: [{
                type: Output
            }], authenticationError: [{
                type: Output
            }] } });

class TokenModule {
    constructor(parentModule) {
        if (parentModule) {
            throw new Error('TokenModule is already loaded. Import it in the AppModule only');
        }
    }
    static forRoot(config) {
        return {
            ngModule: TokenModule,
            providers: [
                AuthenticationService,
                { provide: ServiceConfig, useValue: config }
            ]
        };
    }
}
TokenModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: TokenModule, deps: [{ token: TokenModule, optional: true, skipSelf: true }], target: i0.ɵɵFactoryTarget.NgModule });
TokenModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.1", ngImport: i0, type: TokenModule, imports: [CommonModule] });
TokenModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: TokenModule, imports: [CommonModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: TokenModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [],
                    imports: [
                        CommonModule
                    ],
                    exports: []
                }]
        }], ctorParameters: function () { return [{ type: TokenModule, decorators: [{
                    type: Optional
                }, {
                    type: SkipSelf
                }] }]; } });

/**
 * Generated bundle index. Do not edit.
 */

export { AuthenticationService, ServiceConfig, TokenModule, defaultConfig };
//# sourceMappingURL=cleavelandprice-ngx-lib-authentication-token.mjs.map
