import * as i0 from '@angular/core';
import { EventEmitter, Component, Input, Output, Inject, NgModule } from '@angular/core';
import * as i1 from '@angular/common';
import { CommonModule } from '@angular/common';
import * as i2 from '@angular/forms';
import { FormsModule } from '@angular/forms';
import * as i3 from '@angular/material/button';
import { MatButtonModule } from '@angular/material/button';
import * as i4 from '@angular/material/checkbox';
import { MatCheckboxModule } from '@angular/material/checkbox';
import * as i1$1 from '@angular/material/dialog';
import { MAT_DIALOG_DATA, MatDialogModule } from '@angular/material/dialog';
import * as i6 from '@angular/material/form-field';
import { MatFormFieldModule } from '@angular/material/form-field';
import * as i7 from '@angular/material/input';
import { MatInputModule } from '@angular/material/input';

var ConfirmationDialogMode;
(function (ConfirmationDialogMode) {
    ConfirmationDialogMode[ConfirmationDialogMode["OkCancel"] = 0] = "OkCancel";
    ConfirmationDialogMode[ConfirmationDialogMode["YesNo"] = 1] = "YesNo";
    ConfirmationDialogMode[ConfirmationDialogMode["TrueFalse"] = 2] = "TrueFalse";
    ConfirmationDialogMode[ConfirmationDialogMode["Custom"] = 3] = "Custom";
})(ConfirmationDialogMode || (ConfirmationDialogMode = {}));

var DialogType;
(function (DialogType) {
    DialogType[DialogType["Choice"] = 0] = "Choice";
    DialogType[DialogType["Confirmation"] = 1] = "Confirmation";
    DialogType[DialogType["Input"] = 2] = "Input";
    DialogType[DialogType["Message"] = 3] = "Message";
})(DialogType || (DialogType = {}));

class BaseComponent {
    constructor() {
        // This is so that DialogType can be publish accessible from the HTML template
        this.DialogType = DialogType;
        this.dialogType = DialogType.Message;
        this.closed = new EventEmitter();
        this.ConfirmationDialogMode = ConfirmationDialogMode;
    }
    get customTrueText() {
        return this.data.customTrueFalseText ?
            this.data.customTrueFalseText[0] :
            null;
    }
    get customFalseText() {
        return this.data.customTrueFalseText ?
            this.data.customTrueFalseText[1] :
            null;
    }
    get choices() {
        return this.dialogType === DialogType.Choice ?
            this.data.choices :
            null;
    }
    close() {
        let data;
        switch (this.dialogType) {
            case DialogType.Message:
                data = this.data.checkboxMessage ?
                    {
                        checkbox: this.checkboxValue || false
                    } :
                    null;
                break;
            case DialogType.Input:
                data = this.data.checkboxMessage ?
                    {
                        response: this.userInput,
                        checkbox: this.checkboxValue || false
                    } :
                    this.userInput;
                break;
            case DialogType.Confirmation:
                data = this.data.checkboxMessage ?
                    {
                        response: true,
                        checkbox: this.checkboxValue || false
                    } :
                    true;
                break;
        }
        this.closed.emit(data);
    }
    cancel() {
        let data;
        if (this.dialogType === DialogType.Confirmation) {
            data = this.data.checkboxMessage ?
                {
                    response: false,
                    checkbox: this.checkboxValue || false
                } :
                false;
        }
        this.closed.emit(data);
    }
}
BaseComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: BaseComponent, deps: [], target: i0.ɵɵFactoryTarget.Component });
BaseComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.1", type: BaseComponent, selector: "cp-dialog-base", inputs: { dialogType: "dialogType", data: "data" }, outputs: { closed: "closed" }, ngImport: i0, template: "<h2 *ngIf=\"data?.title\" mat-dialog-title [innerHTML]=\"data.title\"></h2>\n\n<mat-dialog-content>\n    <div *ngIf=\"data?.message\" [innerHTML]=\"data.message\"></div>\n\n    <mat-form-field *ngIf=\"dialogType === DialogType.Input\">\n        <textarea matInput [placeholder]=\"data.placeholder ?? ''\" [(ngModel)]=\"userInput\"></textarea>\n    </mat-form-field>\n\n    <div id=\"checkbox\" *ngIf=\"data?.checkboxMessage\">\n        <mat-checkbox [(ngModel)]=\"checkboxValue\">\n            <span [innerHTML]=\"data.checkboxMessage\"></span>\n        </mat-checkbox>\n    </div>\n</mat-dialog-content>\n\n<mat-dialog-actions>\n    <ng-container *ngIf=\"dialogType !== DialogType.Choice\">\n        <button mat-raised-button (click)=\"close()\" [disabled]=\"dialogType === DialogType.Input && !userInput\">\n            <span [ngSwitch]=\"data.mode\">\n                <span *ngSwitchCase=\"ConfirmationDialogMode.YesNo\">Yes</span>\n                <span *ngSwitchCase=\"ConfirmationDialogMode.TrueFalse\">True</span>\n                <span *ngSwitchCase=\"ConfirmationDialogMode.Custom\">{{ customTrueText }}</span>\n                <span *ngSwitchDefault>OK</span>\n            </span>\n        </button>\n        <button *ngIf=\"dialogType !== DialogType.Message\" mat-raised-button (click)=\"cancel()\">\n            <span [ngSwitch]=\"data.mode\">\n                <span *ngSwitchCase=\"ConfirmationDialogMode.YesNo\">No</span>\n                <span *ngSwitchCase=\"ConfirmationDialogMode.TrueFalse\">False</span>\n                <span *ngSwitchCase=\"ConfirmationDialogMode.Custom\">{{ customFalseText }}</span>\n                <span *ngSwitchDefault>Cancel</span>\n            </span>\n        </button>\n    </ng-container>\n\n    <ng-container *ngIf=\"dialogType === DialogType.Choice\">\n        <button mat-raised-button *ngFor=\"let choice of choices; let i = index\" [matDialogClose]=\"i\">\n            <span>{{ choice }}</span>\n        </button>\n    </ng-container>\n</mat-dialog-actions>", styles: ["mat-form-field{margin-top:2em;width:100%}#checkbox{margin:2em 0}\n"], dependencies: [{ kind: "directive", type: i1.NgForOf, selector: "[ngFor][ngForOf]", inputs: ["ngForOf", "ngForTrackBy", "ngForTemplate"] }, { kind: "directive", type: i1.NgIf, selector: "[ngIf]", inputs: ["ngIf", "ngIfThen", "ngIfElse"] }, { kind: "directive", type: i1.NgSwitch, selector: "[ngSwitch]", inputs: ["ngSwitch"] }, { kind: "directive", type: i1.NgSwitchCase, selector: "[ngSwitchCase]", inputs: ["ngSwitchCase"] }, { kind: "directive", type: i1.NgSwitchDefault, selector: "[ngSwitchDefault]" }, { kind: "directive", type: i2.DefaultValueAccessor, selector: "input:not([type=checkbox])[formControlName],textarea[formControlName],input:not([type=checkbox])[formControl],textarea[formControl],input:not([type=checkbox])[ngModel],textarea[ngModel],[ngDefaultControl]" }, { kind: "directive", type: i2.NgControlStatus, selector: "[formControlName],[ngModel],[formControl]" }, { kind: "directive", type: i2.NgModel, selector: "[ngModel]:not([formControlName]):not([formControl])", inputs: ["name", "disabled", "ngModel", "ngModelOptions"], outputs: ["ngModelChange"], exportAs: ["ngModel"] }, { kind: "component", type: i3.MatButton, selector: "button[mat-button], button[mat-raised-button], button[mat-icon-button],             button[mat-fab], button[mat-mini-fab], button[mat-stroked-button],             button[mat-flat-button]", inputs: ["disabled", "disableRipple", "color"], exportAs: ["matButton"] }, { kind: "component", type: i4.MatCheckbox, selector: "mat-checkbox", inputs: ["disableRipple", "color", "tabIndex"], exportAs: ["matCheckbox"] }, { kind: "directive", type: i1$1.MatDialogClose, selector: "[mat-dialog-close], [matDialogClose]", inputs: ["aria-label", "type", "mat-dialog-close", "matDialogClose"], exportAs: ["matDialogClose"] }, { kind: "directive", type: i1$1.MatDialogTitle, selector: "[mat-dialog-title], [matDialogTitle]", inputs: ["id"], exportAs: ["matDialogTitle"] }, { kind: "directive", type: i1$1.MatDialogContent, selector: "[mat-dialog-content], mat-dialog-content, [matDialogContent]" }, { kind: "directive", type: i1$1.MatDialogActions, selector: "[mat-dialog-actions], mat-dialog-actions, [matDialogActions]", inputs: ["align"] }, { kind: "component", type: i6.MatFormField, selector: "mat-form-field", inputs: ["color", "appearance", "hideRequiredMarker", "hintLabel", "floatLabel"], exportAs: ["matFormField"] }, { kind: "directive", type: i7.MatInput, selector: "input[matInput], textarea[matInput], select[matNativeControl],      input[matNativeControl], textarea[matNativeControl]", inputs: ["disabled", "id", "placeholder", "name", "required", "type", "errorStateMatcher", "aria-describedby", "value", "readonly"], exportAs: ["matInput"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: BaseComponent, decorators: [{
            type: Component,
            args: [{ selector: 'cp-dialog-base', template: "<h2 *ngIf=\"data?.title\" mat-dialog-title [innerHTML]=\"data.title\"></h2>\n\n<mat-dialog-content>\n    <div *ngIf=\"data?.message\" [innerHTML]=\"data.message\"></div>\n\n    <mat-form-field *ngIf=\"dialogType === DialogType.Input\">\n        <textarea matInput [placeholder]=\"data.placeholder ?? ''\" [(ngModel)]=\"userInput\"></textarea>\n    </mat-form-field>\n\n    <div id=\"checkbox\" *ngIf=\"data?.checkboxMessage\">\n        <mat-checkbox [(ngModel)]=\"checkboxValue\">\n            <span [innerHTML]=\"data.checkboxMessage\"></span>\n        </mat-checkbox>\n    </div>\n</mat-dialog-content>\n\n<mat-dialog-actions>\n    <ng-container *ngIf=\"dialogType !== DialogType.Choice\">\n        <button mat-raised-button (click)=\"close()\" [disabled]=\"dialogType === DialogType.Input && !userInput\">\n            <span [ngSwitch]=\"data.mode\">\n                <span *ngSwitchCase=\"ConfirmationDialogMode.YesNo\">Yes</span>\n                <span *ngSwitchCase=\"ConfirmationDialogMode.TrueFalse\">True</span>\n                <span *ngSwitchCase=\"ConfirmationDialogMode.Custom\">{{ customTrueText }}</span>\n                <span *ngSwitchDefault>OK</span>\n            </span>\n        </button>\n        <button *ngIf=\"dialogType !== DialogType.Message\" mat-raised-button (click)=\"cancel()\">\n            <span [ngSwitch]=\"data.mode\">\n                <span *ngSwitchCase=\"ConfirmationDialogMode.YesNo\">No</span>\n                <span *ngSwitchCase=\"ConfirmationDialogMode.TrueFalse\">False</span>\n                <span *ngSwitchCase=\"ConfirmationDialogMode.Custom\">{{ customFalseText }}</span>\n                <span *ngSwitchDefault>Cancel</span>\n            </span>\n        </button>\n    </ng-container>\n\n    <ng-container *ngIf=\"dialogType === DialogType.Choice\">\n        <button mat-raised-button *ngFor=\"let choice of choices; let i = index\" [matDialogClose]=\"i\">\n            <span>{{ choice }}</span>\n        </button>\n    </ng-container>\n</mat-dialog-actions>", styles: ["mat-form-field{margin-top:2em;width:100%}#checkbox{margin:2em 0}\n"] }]
        }], propDecorators: { dialogType: [{
                type: Input
            }], data: [{
                type: Input
            }], closed: [{
                type: Output
            }] } });

class ChoiceComponent {
    constructor(data, dialogRef) {
        this.data = data;
        this.dialogRef = dialogRef;
        this.dialogType = DialogType.Choice;
    }
}
ChoiceComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: ChoiceComponent, deps: [{ token: MAT_DIALOG_DATA }, { token: i1$1.MatDialogRef }], target: i0.ɵɵFactoryTarget.Component });
ChoiceComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.1", type: ChoiceComponent, selector: "ng-component", ngImport: i0, template: "<cp-dialog-base\n  [data]=\"data\"\n  [dialogType]=\"dialogType\"\n  (closed)=\"dialogRef.close($event)\">\n</cp-dialog-base>", styles: [""], dependencies: [{ kind: "component", type: BaseComponent, selector: "cp-dialog-base", inputs: ["dialogType", "data"], outputs: ["closed"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: ChoiceComponent, decorators: [{
            type: Component,
            args: [{ template: "<cp-dialog-base\n  [data]=\"data\"\n  [dialogType]=\"dialogType\"\n  (closed)=\"dialogRef.close($event)\">\n</cp-dialog-base>" }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }, { type: i1$1.MatDialogRef }]; } });

class ConfirmationComponent {
    constructor(data, dialogRef) {
        this.data = data;
        this.dialogRef = dialogRef;
        this.dialogType = DialogType.Confirmation;
    }
}
ConfirmationComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: ConfirmationComponent, deps: [{ token: MAT_DIALOG_DATA }, { token: i1$1.MatDialogRef }], target: i0.ɵɵFactoryTarget.Component });
ConfirmationComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.1", type: ConfirmationComponent, selector: "ng-component", ngImport: i0, template: "<cp-dialog-base\n  [data]=\"data\"\n  [dialogType]=\"dialogType\"\n  (closed)=\"dialogRef.close($event)\">\n</cp-dialog-base>", styles: [""], dependencies: [{ kind: "component", type: BaseComponent, selector: "cp-dialog-base", inputs: ["dialogType", "data"], outputs: ["closed"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: ConfirmationComponent, decorators: [{
            type: Component,
            args: [{ template: "<cp-dialog-base\n  [data]=\"data\"\n  [dialogType]=\"dialogType\"\n  (closed)=\"dialogRef.close($event)\">\n</cp-dialog-base>" }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }, { type: i1$1.MatDialogRef }]; } });

class InputComponent {
    constructor(data, dialogRef) {
        this.data = data;
        this.dialogRef = dialogRef;
        this.dialogType = DialogType.Input;
    }
}
InputComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: InputComponent, deps: [{ token: MAT_DIALOG_DATA }, { token: i1$1.MatDialogRef }], target: i0.ɵɵFactoryTarget.Component });
InputComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.1", type: InputComponent, selector: "ng-component", ngImport: i0, template: "<cp-dialog-base\n  [data]=\"data\"\n  [dialogType]=\"dialogType\"\n  (closed)=\"dialogRef.close($event)\">\n</cp-dialog-base>", styles: [""], dependencies: [{ kind: "component", type: BaseComponent, selector: "cp-dialog-base", inputs: ["dialogType", "data"], outputs: ["closed"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: InputComponent, decorators: [{
            type: Component,
            args: [{ template: "<cp-dialog-base\n  [data]=\"data\"\n  [dialogType]=\"dialogType\"\n  (closed)=\"dialogRef.close($event)\">\n</cp-dialog-base>" }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }, { type: i1$1.MatDialogRef }]; } });

class MessageComponent {
    constructor(data, dialogRef) {
        this.data = data;
        this.dialogRef = dialogRef;
        this.dialogType = DialogType.Message;
    }
}
MessageComponent.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: MessageComponent, deps: [{ token: MAT_DIALOG_DATA }, { token: i1$1.MatDialogRef }], target: i0.ɵɵFactoryTarget.Component });
MessageComponent.ɵcmp = i0.ɵɵngDeclareComponent({ minVersion: "14.0.0", version: "14.2.1", type: MessageComponent, selector: "ng-component", ngImport: i0, template: "<cp-dialog-base\n  [data]=\"data\"\n  [dialogType]=\"dialogType\"\n  (closed)=\"dialogRef.close($event)\">\n</cp-dialog-base>", styles: [""], dependencies: [{ kind: "component", type: BaseComponent, selector: "cp-dialog-base", inputs: ["dialogType", "data"], outputs: ["closed"] }] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: MessageComponent, decorators: [{
            type: Component,
            args: [{ template: "<cp-dialog-base\n  [data]=\"data\"\n  [dialogType]=\"dialogType\"\n  (closed)=\"dialogRef.close($event)\">\n</cp-dialog-base>" }]
        }], ctorParameters: function () { return [{ type: undefined, decorators: [{
                    type: Inject,
                    args: [MAT_DIALOG_DATA]
                }] }, { type: i1$1.MatDialogRef }]; } });

class DialogModule {
}
DialogModule.ɵfac = i0.ɵɵngDeclareFactory({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: DialogModule, deps: [], target: i0.ɵɵFactoryTarget.NgModule });
DialogModule.ɵmod = i0.ɵɵngDeclareNgModule({ minVersion: "14.0.0", version: "14.2.1", ngImport: i0, type: DialogModule, declarations: [BaseComponent,
        ChoiceComponent,
        ConfirmationComponent,
        InputComponent,
        MessageComponent], imports: [CommonModule,
        FormsModule,
        MatButtonModule,
        MatCheckboxModule,
        MatDialogModule,
        MatFormFieldModule,
        MatInputModule], exports: [BaseComponent,
        ChoiceComponent,
        ConfirmationComponent,
        InputComponent,
        MessageComponent] });
DialogModule.ɵinj = i0.ɵɵngDeclareInjector({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: DialogModule, imports: [CommonModule,
        FormsModule,
        MatButtonModule,
        MatCheckboxModule,
        MatDialogModule,
        MatFormFieldModule,
        MatInputModule] });
i0.ɵɵngDeclareClassMetadata({ minVersion: "12.0.0", version: "14.2.1", ngImport: i0, type: DialogModule, decorators: [{
            type: NgModule,
            args: [{
                    declarations: [
                        BaseComponent,
                        ChoiceComponent,
                        ConfirmationComponent,
                        InputComponent,
                        MessageComponent
                    ],
                    imports: [
                        CommonModule,
                        FormsModule,
                        MatButtonModule,
                        MatCheckboxModule,
                        MatDialogModule,
                        MatFormFieldModule,
                        MatInputModule
                    ],
                    exports: [
                        BaseComponent,
                        ChoiceComponent,
                        ConfirmationComponent,
                        InputComponent,
                        MessageComponent
                    ]
                }]
        }] });

/**
 * Generated bundle index. Do not edit.
 */

export { BaseComponent, ChoiceComponent, ConfirmationComponent, ConfirmationDialogMode, DialogModule, DialogType, InputComponent, MessageComponent };
//# sourceMappingURL=cleavelandprice-ngx-lib-dialog.mjs.map
